<?php
header('Content-Type: text/html; charset=utf-8');

function parse_size($size_str) {
    $size_str = trim($size_str);
    $last = strtolower($size_str[strlen($size_str) - 1]);
    switch ($last) {
        case 'g':
            $size = (float)$size_str * 1024 * 1024 * 1024;
            break;
        case 'm':
            $size = (float)$size_str * 1024 * 1024;
            break;
        case 'k':
            $size = (float)$size_str * 1024;
            break;
        default:
            $size = (float)$size_str;
            break;
    }
    return $size;
}

function check_php_version() {
    return phpversion();
}

function check_database_version() {
    $db_version = 'Unknown'; // Default value
    $db_status = '<span class="fail">Check Failed</span>'; // Default status

    if (extension_loaded('mysqli') || extension_loaded('pdo_mysql')) {
        $db_version = 'MySQL 8.0 or later'; // Placeholder
        $db_status = '<span class="pass">Available</span>';
    }

    return ['version' => $db_version, 'status' => $db_status];
}

function check_web_server() {
    $server = 'Not Detected';
    $version = 'Unknown';
    $status = '<span class="fail">Not Detected</span>';

    if (isset($_SERVER['SERVER_SOFTWARE'])) {
        $server_software = $_SERVER['SERVER_SOFTWARE'];
        if (strpos($server_software, 'nginx') !== false) {
            $server = 'Nginx';
            $status = '<span class="pass">Installed</span>';
            $version = preg_replace('/.*nginx\/([0-9\.]+).*/', '$1', $server_software);
        } elseif (strpos($server_software, 'Apache') !== false) {
            $server = 'Apache';
            $status = '<span class="pass">Installed</span>';
            $version = preg_replace('/.*Apache\/([0-9\.]+).*/', '$1', $server_software);
        }
    }

    return ['server' => $server, 'version' => $version, 'status' => $status];
}

function check_disabled_functions() {
    $disabled_functions = ini_get('disable_functions');
    if ($disabled_functions) {
        $disabled_functions_list = explode(',', $disabled_functions);
        return array_map('trim', $disabled_functions_list);
    } else {
        return [];
    }
}

// Determine the language
$language = isset($_POST['lang']) ? $_POST['lang'] : 'zh';

// Define translations
$translations = [
    'zh' => [
        'php_version' => 'PHP 版本',
        'installed_extensions' => '已安装的 PHP 扩展',
        'php_settings' => 'PHP 配置设置',
        'database_check' => '数据库检查',
        'web_server_check' => 'Web 服务器检查',
        'disabled_functions' => '禁用的函数',
        'size' => '大小',
        'suggested' => '建议',
        'status' => '状态',
        'current' => '当前值',
        'setting' => '设置项',
        'website' => '网站',
        'switch_to_english' => '切换到英文',
        'switch_to_chinese' => '切换到中文',
        'db_version' => '数据库版本',
        'db_status' => '数据库状态',
        'web_server' => 'Web 服务器',
        'web_server_status' => 'Web 服务器状态',
        'web_server_version' => 'Web 服务器版本',
        'disabled_function_suggestion' => '禁用的核心 PHP 函数可能会影响 XenForo 的正常运行。请在 PHP 配置中启用以下函数：'
    ],
    'en' => [
        'php_version' => 'PHP Version',
        'installed_extensions' => 'Installed PHP Extensions',
        'php_settings' => 'PHP Configuration Settings',
        'database_check' => 'Database Check',
        'web_server_check' => 'Web Server Check',
        'disabled_functions' => 'Disabled Functions',
        'size' => 'Size',
        'suggested' => 'Suggested',
        'status' => 'Status',
        'current' => 'Current Value',
        'setting' => 'Setting',
        'website' => 'Website',
        'switch_to_english' => 'Switch to English',
        'switch_to_chinese' => 'Switch to Chinese',
        'db_version' => 'Database Version',
        'db_status' => 'Database Status',
        'web_server' => 'Web Server',
        'web_server_status' => 'Web Server Status',
        'web_server_version' => 'Web Server Version',
        'disabled_function_suggestion' => 'Disabled core PHP functions may affect XenForo functionality. Please enable the following functions in your PHP configuration:'
    ]
];

// Get current translation
$translation = $translations[$language];

// Perform checks
$php_version = check_php_version();
$db_check = check_database_version();
$server_check = check_web_server();
$disabled_functions = check_disabled_functions();
?>

<!DOCTYPE html>
<html lang="<?php echo $language; ?>">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $translation['php_version']; ?> - XenForo <?php echo $translation['website']; ?> 环境检查</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background: linear-gradient(to right, #f5f7fa, #c3cfe2);
            color: #333;
            margin: 0;
            padding: 0;
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }
        h1, h2 {
            text-align: center;
            color: #007bff;
            margin: 20px 0;
        }
        h2 {
            color: #333;
        }
        table {
            border-collapse: collapse;
            width: 80%;
            margin: 20px auto;
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0,0,0,0.2);
        }
        th, td {
            border: 1px solid #ddd;
            padding: 8px;
            text-align: center;
        }
        th {
            background-color: #007bff;
            color: white;
        }
        .pass {
            color: green;
        }
        .fail {
            color: red;
        }
        button {
            background: linear-gradient(45deg, #007bff, #00d2ff);
            border: none;
            border-radius: 5px;
            color: white;
            padding: 8px 16px;
            margin: 8px;
            cursor: pointer;
            font-size: 14px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.2);
            transition: background 0.3s, box-shadow 0.3s;
        }
        button:hover {
            background: linear-gradient(45deg, #00d2ff, #007bff);
            box-shadow: 0 4px 6px rgba(0,0,0,0.3);
        }
        .form-container {
            text-align: center;
            margin: 20px;
        }
        .footer {
            text-align: center;
            margin-top: auto;
            padding: 20px;
            background: #007bff;
            color: white;
        }
        .footer a {
            color: #00d2ff;
            text-decoration: none;
        }
        .footer a:hover {
            text-decoration: underline;
        }
    </style>
</head>
<body>
    <h1><?php echo $translation['php_version']; ?> - XenForo <?php echo $translation['website']; ?> 安装环境检查</h1>

    <h2><?php echo $translation['php_version']; ?></h2>
    <table>
        <tr>
            <th><?php echo $translation['php_version']; ?></th>
            <td><?php echo $php_version; ?></td>
        </tr>
    </table>

    <h2><?php echo $translation['installed_extensions']; ?></h2>
    <table>
        <tr>
            <th>Extension</th>
            <th>Status</th>
        </tr>
        <?php
        $required_extensions = ['bcmath', 'curl', 'gd', 'json', 'mbstring', 'openssl', 'pdo', 'pdo_mysql', 'xml', 'zip'];
        foreach ($required_extensions as $ext) {
            $status = extension_loaded($ext) ? '<span class="pass">Installed</span>' : '<span class="fail">Not Installed</span>';
            echo "<tr><td>$ext</td><td>$status</td></tr>";
        }
        ?>
    </table>

    <h2><?php echo $translation['php_settings']; ?></h2>
    <table>
        <tr>
            <th><?php echo $translation['setting']; ?></th>
            <th><?php echo $translation['current']; ?></th>
            <th><?php echo $translation['suggested']; ?></th>
            <th><?php echo $translation['status']; ?></th>
        </tr>
        <?php
        $settings = [
            'upload_max_filesize' => '2M',
            'post_max_size' => '8M'
        ];

        foreach ($settings as $key => $suggested) {
            $current = ini_get($key);
            $current_size = parse_size($current);
            $suggested_size = parse_size($suggested);
            $status = ($current_size >= $suggested_size) ? '<span class="pass">Compliant</span>' : '<span class="fail">Non-Compliant</span>';
            echo "<tr><td>$key</td><td>$current</td><td>$suggested</td><td>$status</td></tr>";
        }
        ?>
    </table>

    <h2><?php echo $translation['database_check']; ?></h2>
    <table>
        <tr>
            <th><?php echo $translation['db_version']; ?></th>
            <th><?php echo $translation['db_status']; ?></th>
        </tr>
        <tr>
            <td><?php echo $db_check['version']; ?></td>
            <td><?php echo $db_check['status']; ?></td>
        </tr>
    </table>

    <h2><?php echo $translation['web_server_check']; ?></h2>
    <table>
        <tr>
            <th><?php echo $translation['web_server']; ?></th>
            <th><?php echo $translation['web_server_version']; ?></th>
            <th><?php echo $translation['web_server_status']; ?></th>
        </tr>
        <tr>
            <td><?php echo $server_check['server']; ?></td>
            <td><?php echo $server_check['version']; ?></td>
            <td><?php echo $server_check['status']; ?></td>
        </tr>
    </table>

    <h2><?php echo $translation['disabled_functions']; ?></h2>
    <table>
        <tr>
            <th>Function</th>
            <th>Status</th>
            <th>Suggestion</th>
        </tr>
        <?php
        $core_functions = ['exec', 'proc_open', 'popen'];
        foreach ($core_functions as $func) {
            $status = in_array($func, $disabled_functions) ? '<span class="fail">Disabled</span>' : '<span class="pass">Enabled</span>';
            $suggestion = in_array($func, $disabled_functions) ? $translation['disabled_function_suggestion'] : '';
            echo "<tr><td>$func</td><td>$status</td><td>$suggestion</td></tr>";
        }
        ?>
    </table>

    <div class="form-container">
        <form method="post" action="">
            <button type="submit" name="lang" value="zh"><?php echo $translation['switch_to_chinese']; ?></button>
            <button type="submit" name="lang" value="en"><?php echo $translation['switch_to_english']; ?></button>
        </form>
    </div>

    <div class="footer">
        <p>&copy; <?php echo date('Y'); ?> <a href="https://oksgo.com">OKSGO.COM</a></p>
    </div>
</body>
</html>
